@@ -6,10 +6,14 @@
 #define CLIPBOARD_H
 
 #include <QObject>
+#include <qqmlintegration.h>
 
 class Clipboard : public QObject
 {
     Q_OBJECT
+    QML_ELEMENT
+    QML_SINGLETON
+
     Q_PROPERTY(QString text READ text WRITE setText NOTIFY textChanged)
 
 public:
